# serenity.types.python

This base repository contains shared classes and enumerations common to the Serenity platform and the public SDK.
It is not meant to be used or installed on a standalone basis and is intended for use by Serenity clients only.
